==> kde-workspace-4.11.13p1.tgz: lib/cmake/KDE4Workspace/KDE4WorkspaceLibraryTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDE4Workspace__kephal" for configuration "Release"
set_property(TARGET KDE4Workspace__kephal APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__kephal PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkephal.so.51.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__kephal )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__kephal "/usr/local/lib/libkephal.so.51.0" )

# Import target "KDE4Workspace__kworkspace" for configuration "Release"
set_property(TARGET KDE4Workspace__kworkspace APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__kworkspace PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui;KDE4__plasma"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkworkspace.so.51.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__kworkspace )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__kworkspace "/usr/local/lib/libkworkspace.so.51.0" )

# Import target "KDE4Workspace__plasmaclock" for configuration "Release"
set_property(TARGET KDE4Workspace__plasmaclock APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__plasmaclock PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__plasma;KDE4__kdeui;KDE4__kio;KDE4Workspace__kephal;KDEPIMLibs__kholidays"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libplasmaclock.so.51.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__plasmaclock )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__plasmaclock "/usr/local/lib/libplasmaclock.so.51.0" )

# Import target "KDE4Workspace__plasmagenericshell" for configuration "Release"
set_property(TARGET KDE4Workspace__plasmagenericshell APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__plasmagenericshell PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__plasma;KDE4__kdeui;KDE4__kfile;KDE4Workspace__kworkspace;KDE4Workspace__kephal"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libplasmagenericshell.so.51.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__plasmagenericshell )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__plasmagenericshell "/usr/local/lib/libplasmagenericshell.so.51.0" )

# Import target "KDE4Workspace__taskmanager" for configuration "Release"
set_property(TARGET KDE4Workspace__taskmanager APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__taskmanager PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4Workspace__processcore;kactivities;KDE4__kdeui;KDE4__kio;KDE4Workspace__kephal"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libtaskmanager.so.51.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__taskmanager )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__taskmanager "/usr/local/lib/libtaskmanager.so.51.0" )

# Import target "KDE4Workspace__lsofui" for configuration "Release"
set_property(TARGET KDE4Workspace__lsofui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__lsofui PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/liblsofui.so.51.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__lsofui )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__lsofui "/usr/local/lib/liblsofui.so.51.0" )

# Import target "KDE4Workspace__processcore" for configuration "Release"
set_property(TARGET KDE4Workspace__processcore APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__processcore PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kdecore"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libprocesscore.so.51.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__processcore )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__processcore "/usr/local/lib/libprocesscore.so.51.0" )

# Import target "KDE4Workspace__processui" for configuration "Release"
set_property(TARGET KDE4Workspace__processui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__processui PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kdeui;KDE4Workspace__processcore"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libprocessui.so.51.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__processui )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__processui "/usr/local/lib/libprocessui.so.51.0" )

# Import target "KDE4Workspace__ksignalplotter" for configuration "Release"
set_property(TARGET KDE4Workspace__ksignalplotter APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__ksignalplotter PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kdeui"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libksignalplotter.so.51.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__ksignalplotter )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__ksignalplotter "/usr/local/lib/libksignalplotter.so.51.0" )

# Import target "KDE4Workspace__ksgrd" for configuration "Release"
set_property(TARGET KDE4Workspace__ksgrd APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__ksgrd PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdecore"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libksgrd.so.51.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__ksgrd )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__ksgrd "/usr/local/lib/libksgrd.so.51.0" )

# Import target "KDE4Workspace__kdecorations" for configuration "Release"
set_property(TARGET KDE4Workspace__kdecorations APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__kdecorations PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kdeui"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkdecorations.so.51.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__kdecorations )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__kdecorations "/usr/local/lib/libkdecorations.so.51.0" )

# Import target "KDE4Workspace__kwineffects" for configuration "Release"
set_property(TARGET KDE4Workspace__kwineffects APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__kwineffects PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkwineffects.so.51.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__kwineffects )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__kwineffects "/usr/local/lib/libkwineffects.so.51.0" )

# Import target "KDE4Workspace__kwinglutils" for configuration "Release"
set_property(TARGET KDE4Workspace__kwinglutils APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__kwinglutils PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui;KDE4Workspace__kwineffects"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "/usr/X11R6/lib/libGL.so.15.0;/usr/X11R6/lib/libGL.so.15.0"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkwinglutils.so.51.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__kwinglutils )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__kwinglutils "/usr/local/lib/libkwinglutils.so.51.0" )

# Import target "KDE4Workspace__kscreensaver" for configuration "Release"
set_property(TARGET KDE4Workspace__kscreensaver APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__kscreensaver PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkscreensaver.so.51.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__kscreensaver )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__kscreensaver "/usr/local/lib/libkscreensaver.so.51.0" )

# Import target "KDE4Workspace__weather_ion" for configuration "Release"
set_property(TARGET KDE4Workspace__weather_ion APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__weather_ion PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kdeui;KDE4__kio;KDE4__plasma"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libweather_ion.so.51.0"
  IMPORTED_NO_SONAME_RELEASE "TRUE"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__weather_ion )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__weather_ion "/usr/local/lib/libweather_ion.so.51.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> kde-workspace-4.11.21p32.tgz: lib/cmake/KDE4Workspace/KDE4WorkspaceLibraryTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDE4Workspace__kephal" for configuration "Release"
set_property(TARGET KDE4Workspace__kephal APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__kephal PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkephal.so.51.0"
  IMPORTED_SONAME_RELEASE "libkephal.so.51.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__kephal )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__kephal "/usr/local/lib/libkephal.so.51.0" )

# Import target "KDE4Workspace__kworkspace" for configuration "Release"
set_property(TARGET KDE4Workspace__kworkspace APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__kworkspace PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui;KDE4__plasma"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkworkspace.so.51.0"
  IMPORTED_SONAME_RELEASE "libkworkspace.so.51.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__kworkspace )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__kworkspace "/usr/local/lib/libkworkspace.so.51.0" )

# Import target "KDE4Workspace__plasmaclock" for configuration "Release"
set_property(TARGET KDE4Workspace__plasmaclock APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__plasmaclock PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__plasma;KDE4__kdeui;KDE4__kio;KDE4Workspace__kephal;KDEPIMLibs__kholidays"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libplasmaclock.so.51.0"
  IMPORTED_SONAME_RELEASE "libplasmaclock.so.51.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__plasmaclock )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__plasmaclock "/usr/local/lib/libplasmaclock.so.51.0" )

# Import target "KDE4Workspace__plasmagenericshell" for configuration "Release"
set_property(TARGET KDE4Workspace__plasmagenericshell APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__plasmagenericshell PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__plasma;KDE4__kdeui;KDE4__kfile;KDE4Workspace__kworkspace;KDE4Workspace__kephal"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libplasmagenericshell.so.51.0"
  IMPORTED_SONAME_RELEASE "libplasmagenericshell.so.51.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__plasmagenericshell )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__plasmagenericshell "/usr/local/lib/libplasmagenericshell.so.51.0" )

# Import target "KDE4Workspace__taskmanager" for configuration "Release"
set_property(TARGET KDE4Workspace__taskmanager APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__taskmanager PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4Workspace__processcore;kactivities;KDE4__kdeui;KDE4__kio;KDE4Workspace__kephal"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libtaskmanager.so.51.0"
  IMPORTED_SONAME_RELEASE "libtaskmanager.so.51.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__taskmanager )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__taskmanager "/usr/local/lib/libtaskmanager.so.51.0" )

# Import target "KDE4Workspace__lsofui" for configuration "Release"
set_property(TARGET KDE4Workspace__lsofui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__lsofui PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/liblsofui.so.51.0"
  IMPORTED_SONAME_RELEASE "liblsofui.so.51.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__lsofui )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__lsofui "/usr/local/lib/liblsofui.so.51.0" )

# Import target "KDE4Workspace__processcore" for configuration "Release"
set_property(TARGET KDE4Workspace__processcore APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__processcore PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kdecore"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libprocesscore.so.51.0"
  IMPORTED_SONAME_RELEASE "libprocesscore.so.51.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__processcore )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__processcore "/usr/local/lib/libprocesscore.so.51.0" )

# Import target "KDE4Workspace__processui" for configuration "Release"
set_property(TARGET KDE4Workspace__processui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__processui PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kdeui;KDE4Workspace__processcore"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libprocessui.so.51.0"
  IMPORTED_SONAME_RELEASE "libprocessui.so.51.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__processui )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__processui "/usr/local/lib/libprocessui.so.51.0" )

# Import target "KDE4Workspace__ksignalplotter" for configuration "Release"
set_property(TARGET KDE4Workspace__ksignalplotter APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__ksignalplotter PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kdeui"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libksignalplotter.so.51.0"
  IMPORTED_SONAME_RELEASE "libksignalplotter.so.51.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__ksignalplotter )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__ksignalplotter "/usr/local/lib/libksignalplotter.so.51.0" )

# Import target "KDE4Workspace__ksgrd" for configuration "Release"
set_property(TARGET KDE4Workspace__ksgrd APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__ksgrd PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdecore"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libksgrd.so.51.0"
  IMPORTED_SONAME_RELEASE "libksgrd.so.51.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__ksgrd )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__ksgrd "/usr/local/lib/libksgrd.so.51.0" )

# Import target "KDE4Workspace__kdecorations" for configuration "Release"
set_property(TARGET KDE4Workspace__kdecorations APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__kdecorations PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kdeui"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkdecorations.so.51.0"
  IMPORTED_SONAME_RELEASE "libkdecorations.so.51.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__kdecorations )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__kdecorations "/usr/local/lib/libkdecorations.so.51.0" )

# Import target "KDE4Workspace__kwineffects" for configuration "Release"
set_property(TARGET KDE4Workspace__kwineffects APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__kwineffects PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkwineffects.so.51.0"
  IMPORTED_SONAME_RELEASE "libkwineffects.so.51.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__kwineffects )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__kwineffects "/usr/local/lib/libkwineffects.so.51.0" )

# Import target "KDE4Workspace__kwinglutils" for configuration "Release"
set_property(TARGET KDE4Workspace__kwinglutils APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__kwinglutils PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kdeui;KDE4Workspace__kwineffects"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "/usr/X11R6/lib/libGL.so.17.1;/usr/X11R6/lib/libGL.so.17.1"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkwinglutils.so.51.0"
  IMPORTED_SONAME_RELEASE "libkwinglutils.so.51.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__kwinglutils )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__kwinglutils "/usr/local/lib/libkwinglutils.so.51.0" )

# Import target "KDE4Workspace__kscreensaver" for configuration "Release"
set_property(TARGET KDE4Workspace__kscreensaver APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__kscreensaver PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDE4__kio"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libkscreensaver.so.51.0"
  IMPORTED_SONAME_RELEASE "libkscreensaver.so.51.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__kscreensaver )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__kscreensaver "/usr/local/lib/libkscreensaver.so.51.0" )

# Import target "KDE4Workspace__weather_ion" for configuration "Release"
set_property(TARGET KDE4Workspace__weather_ion APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDE4Workspace__weather_ion PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "KDE4__kdeui;KDE4__kio;KDE4__plasma"
  IMPORTED_LOCATION_RELEASE "/usr/local/lib/libweather_ion.so.51.0"
  IMPORTED_SONAME_RELEASE "libweather_ion.so.51.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS KDE4Workspace__weather_ion )
list(APPEND _IMPORT_CHECK_FILES_FOR_KDE4Workspace__weather_ion "/usr/local/lib/libweather_ion.so.51.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
